@@ -42,7 +42,6 @@ from .backreferences import (
     identify_names,
 )
 from .block_parser import BlockParser
-from .docs_resolv import _write_code_obj
 from .interactive_example import (
     _add_jupyterlite_badge_logo,
     gen_binder_rst,
@@ -60,8 +59,10 @@ from .scrapers import (
 from .utils import (
     _W_KW,
     _collect_gallery_files,
+    _combine_backreferences,
     _format_toctree,
     _replace_md5,
+    _write_json,
     get_md5sum,
     optipng,
     scale_image,
@@ -509,7 +510,7 @@ def generate_dir_rst(
     seen_backrefs,
     is_subsection=True,
 ):
-    """Generate the gallery reStructuredText for an example directory.
+    """Generate output example reST files for one gallery (sub)directory.
 
     Parameters
     ----------
@@ -539,6 +540,11 @@ def generate_dir_rst(
          with keys "t", "mem", "src_file", and "target_dir".
     toctree_items: list,
         List of example file names we generated ReST for.
+    backrefs_dir : dict[str, tuple]
+        Dictionary where value is the backreference object and value
+        is a tuple containing: example filename, full path to example source directory,
+        full path to example target directory, intro, title.
+
     """
     index_content = ""
     # `_get_gallery_header` returns `None` if user supplied `index.rst`
@@ -566,7 +572,7 @@ def generate_dir_rst(
     listdir = _collect_gallery_files([src_dir], gallery_conf)
     # sort them
     sorted_listdir = sorted(
-        listdir, key=_get_class(gallery_conf, "within_subsection_order")(src_dir)
+        listdir, key=_get_callables(gallery_conf, "within_subsection_order", src_dir)[0]
     )
 
     # Add div containing all thumbnails;
@@ -582,6 +588,8 @@ def generate_dir_rst(
         length=len(sorted_listdir),
     )
 
+    backrefs_dir = {}
+
     parallel = list
     p_fun = generate_file_rst
     if gallery_conf["parallel"]:
@@ -625,15 +633,17 @@ def generate_dir_rst(
 
         # Write backreferences
         if "backrefs" in out_vars:
-            _write_backreferences(
+            backrefs_example = _write_backreferences(
                 out_vars["backrefs"],
                 seen_backrefs,
                 gallery_conf,
+                src_dir,
                 target_dir,
                 fname,
                 intro,
                 title,
             )
+            _combine_backreferences(backrefs_dir, backrefs_example)
 
     # Close thumbnail parent div
     index_content += THUMBNAIL_PARENT_DIV_CLOSE
@@ -660,6 +670,7 @@ def generate_dir_rst(
         index_content,
         costs,
         toctree_filenames,
+        backrefs_dir,
     )
 
 
@@ -888,7 +899,7 @@ def _get_last_repr(capture_repr, ___):
 
 
 def _get_code_output(
-    is_last_expr, example_globals, gallery_conf, logging_tee, images_rst, file_conf
+    is_last_expr, example_globals, gallery_conf, logging_tee, images_rst, capture_repr
 ):
     """Obtain standard output and html output in reST.
 
@@ -921,7 +932,6 @@ def _get_code_output(
         ignore_repr = False
         if gallery_conf["ignore_repr_types"]:
             ignore_repr = re.search(gallery_conf["ignore_repr_types"], str(type(___)))
-        capture_repr = file_conf.get("capture_repr", gallery_conf["capture_repr"])
         if capture_repr != () and not ignore_repr:
             last_repr, repr_meth = _get_last_repr(capture_repr, ___)
 
@@ -1000,12 +1010,30 @@ def execute_code_block(
     sys.path.append(os.getcwd())
 
     # Save figures unless there is a `sphinx_gallery_defer_figures` flag
-    match = re.search(
+    defer_figs_match = re.search(
         r"^[\ \t]*#\s*sphinx_gallery_defer_figures[\ \t]*\n?",
         block.content,
         re.MULTILINE,
     )
-    need_save_figures = match is None
+    need_save_figures = defer_figs_match is None
+
+    block_conf = py_source_parser.extract_file_config(block.content)
+
+    # Add `sphinx_gallery_multi_image_block` setting to block variables
+    # (extract config rather than just regex search since the option's value is needed)
+    script_vars["multi_image"] = block_conf.get("multi_image_block")
+
+    # Determine the block's `capture_repr` value by prioritising the block-level
+    # `sphinx_gallery_capture_repr_block` setting, then the file-level
+    # `sphinx_gallery_capture_repr` setting, and finally the
+    # global `capture_repr` gallery setting.
+    capture_repr = block_conf.get(
+        "capture_repr_block",
+        file_conf.get("capture_repr", gallery_conf["capture_repr"]),
+    )
+
+    # Add file_conf to script_vars to be read by image scrapers
+    script_vars["file_conf"] = file_conf
 
     try:
         # The "compile" step itself can fail on a SyntaxError, so just prepend
@@ -1050,7 +1078,7 @@ def execute_code_block(
             gallery_conf,
             logging_tee,
             images_rst,
-            file_conf,
+            capture_repr,
         )
     finally:
         _reset_cwd_syspath(cwd, sys_path)
@@ -1236,7 +1264,7 @@ def _get_backreferences(gallery_conf, script_vars, script_blocks, node, target_f
     ref_regex = _make_ref_regex(gallery_conf["default_role"])
     example_code_obj = identify_names(script_blocks, ref_regex, global_variables, node)
     if example_code_obj:
-        _write_code_obj(target_file, example_code_obj)
+        _write_json(target_file, example_code_obj, ".codeobj")
     exclude_regex = gallery_conf["exclude_implicit_doc_regex"]
 
     def _normalize_name(cobj):
@@ -1606,46 +1634,32 @@ def save_rst_example(
     _replace_md5(write_file_new, mode="t")
 
 
-def _get_class(gallery_conf, key):
-    """Get a class for the given conf key."""
-    what = f"sphinx_gallery_conf[{repr(key)}]"
-    val = gallery_conf[key]
-    if key == "within_subsection_order":
-        alias = (  # convenience aliases
-            "ExampleTitleSortKey",
-            "FileNameSortKey",
-            "FileSizeSortKey",
-            "NumberOfCodeLinesSortKey",
-        )
-        if val in alias:
-            val = f"sphinx_gallery.sorting.{val}"
-    if isinstance(val, str):
-        if "." not in val:
-            raise ConfigError(
-                f"{what} must be a fully qualified name string, got {val}"
-            )
-        mod, attr = val.rsplit(".", 1)
-        try:
-            val = getattr(importlib.import_module(mod), attr)
-        except Exception:
-            raise ConfigError(
-                f"{what} must be a fully qualified name string, could not import "
-                f"{attr} from {mod}"
-            )
-    if not inspect.isclass(val):
-        raise ConfigError(
-            f"{what} must be 1) a fully qualified name (string) that resolves "
-            f"to a class or 2) or a class itself, got {val.__class__.__name__} "
-            f"({repr(val)})"
-        )
-    return val
+def _get_callables(gallery_conf, key, src_dir=None):
+    """Get callables for the given conf key, returning tuple of callable(s).
 
+    If value is a string, import, with the following exceptions:
 
-def _get_callables(gallery_conf, key):
-    """Get callables for the given conf key, returning tuple of callable(s)."""
-    singletons = ("reset_argv", "minigallery_sort_order", "subsection_order")
+    * `within_subsection_order` - add full path if value is a built-in aliases,
+      instantiate if value is a class
+    * `image_scrapers` - get value from `_scraper_dict` or import module and
+      get `_get_sg_image_scraper` attribute
+    * `reset_modules` - get value from `_reset_dict`
+    """
+    builtin_aliases = (
+        "ExampleTitleSortKey",
+        "FileNameSortKey",
+        "FileSizeSortKey",
+        "NumberOfCodeLinesSortKey",
+    )
+    singletons = (
+        "reset_argv",
+        "minigallery_sort_order",
+        "subsection_order",
+        "within_subsection_order",
+    )
     # the following should be the case (internal use only):
     assert key in ("image_scrapers", "reset_modules", "jupyterlite") + singletons, key
+    # Get correct config value and ensure it's a list
     which = gallery_conf[key]
     if key == "jupyterlite":
         which = [which["notebook_modification_function"]]
@@ -1654,14 +1668,21 @@ def _get_callables(gallery_conf, key):
     if not isinstance(which, (tuple, list)):
         which = [which]
     which = list(which)
+
     for wi, what in enumerate(which):
+        # Get readable string, for error message
         if key == "jupyterlite":
             readable = f"{key}['notebook_modification_function']"
         elif key in singletons:
             readable = f"{key}={repr(what)}"
         else:
             readable = f"{key}[{wi}]={repr(what)}"
+        # Import string FQNs or get value from dict
         if isinstance(what, str):
+            # use fully qualified name to resolve builtin callable classes
+            # (otherwise not serializable)
+            if what in builtin_aliases:
+                what = f"sphinx_gallery.sorting.{what}"
             if "." in what:
                 mod, attr = what.rsplit(".", 1)
                 try:
@@ -1686,6 +1707,10 @@ def _get_callables(gallery_conf, key):
                     raise ConfigError(f"Unknown string option for {readable}: {what}")
                 what = _reset_dict[what]
             which[wi] = what
+        # make sure classes get instantiated (so they become callable)
+        if key == "within_subsection_order" and inspect.isclass(what):
+            what = what(src_dir)
+            which[wi] = what
         if inspect.isclass(what):
             raise ConfigError(
                 f"Got class rather than callable instance for {readable}: {what}"
