@@ -41,7 +41,7 @@ from sphinx_gallery.utils import (
 #
 # total number of plot_*.py files in
 # (examples + examples_rst_index + examples_with_rst + examples_README_header)
-N_EXAMPLES = 17 + 3 + 2 + 1
+N_EXAMPLES = 19 + 3 + 2 + 1
 N_FAILING = 4
 N_GOOD = N_EXAMPLES - N_FAILING  # galleries that run w/o error
 # passthroughs and non-executed examples in
@@ -409,6 +409,36 @@ def test_thumbnail_expected_failing_examples(sphinx_app, tmpdir):
     assert corr < 0.7  # i.e. thumbnail and "BROKEN" stamp are not identical
 
 
+def test_multi_image(sphinx_app):
+    """Test `sphinx_gallery_multi_image(_block)` variables."""
+    generated_examples_dir = op.join(sphinx_app.outdir, "auto_examples")
+
+    # Check file-wide `sphinx_gallery_multi_image="single"` produces no multi-img
+    html_fname = op.join(generated_examples_dir, "plot_multi_image_separate.html")
+    with codecs.open(html_fname, "r", "utf-8") as fid:
+        html = fid.read()
+    assert "sphx-glr-single-img" in html
+    assert "sphx-glr-multi-img" not in html
+
+    # Check block-specific `sphinx_gallery_multi_image_block` produces mixed img classes
+    html_fname = op.join(generated_examples_dir, "plot_multi_image_block_separate.html")
+    with codecs.open(html_fname, "r", "utf-8") as fid:
+        html = fid.read()
+    # find start of each code block
+    matches = re.finditer('<div class="highlight-Python notranslate">', html)
+    starts = [match.start() for match in matches] + [-1]
+    assert len(starts) == 4  # 3 code block plus an extra for end index
+    for block_idx, (start, end) in enumerate(zip(starts[:-1], starts[1:])):
+        # ignore first code block (just imports)
+        block_html = html[start:end]
+        if block_idx == 1:  # multi-img classes for this code block
+            assert "sphx-glr-multi-img" in block_html
+            assert "sphx-glr-single-img" not in block_html
+        elif block_idx == 2:  # single-img classes for this code block
+            assert "sphx-glr-single-img" in block_html
+            assert "sphx-glr-multi-img" not in block_html
+
+
 def test_command_line_args_img(sphinx_app):
     generated_examples_dir = op.join(sphinx_app.outdir, "auto_examples")
     thumb_fname = "../_images/sphx_glr_plot_command_line_args_thumb.png"
@@ -822,6 +852,8 @@ def test_rebuild(tmpdir_factory, sphinx_app):
     generated_backrefs_0 = sorted(
         op.join(old_src_dir, "gen_modules", "backreferences", f)
         for f in os.listdir(op.join(old_src_dir, "gen_modules", "backreferences"))
+        # Exclude backreferences_all.json` which is changed when any example is run
+        if "backreferences_all.json" not in f
     )
     generated_rst_0 = sorted(
         op.join(old_src_dir, "auto_examples", f)
@@ -889,7 +921,7 @@ def test_rebuild(tmpdir_factory, sphinx_app):
     else:
         assert (
             re.match(
-                ".*[0|1] added, ([1-9]|10) changed, 0 removed$.*",
+                ".*[0|1] added, ([1-9]|1[0-1]) changed, 0 removed$.*",
                 status,
                 re.MULTILINE | re.DOTALL,
             )
@@ -914,6 +946,8 @@ def test_rebuild(tmpdir_factory, sphinx_app):
     generated_backrefs_1 = sorted(
         op.join(new_app.srcdir, "gen_modules", "backreferences", f)
         for f in os.listdir(op.join(new_app.srcdir, "gen_modules", "backreferences"))
+        # Exclude backreferences_all.json` which is changed when any example is run
+        if "backreferences_all.json" not in f
     )
     generated_rst_1 = sorted(
         op.join(new_app.srcdir, "auto_examples", f)
@@ -1087,6 +1121,8 @@ def _rerun(
     generated_backrefs_1 = sorted(
         op.join(new_app.srcdir, "gen_modules", "backreferences", f)
         for f in os.listdir(op.join(new_app.srcdir, "gen_modules", "backreferences"))
+        # Exclude backreferences_all.json` which is changed when any example is run
+        if "backreferences_all.json" not in f
     )
     generated_rst_1 = sorted(
         op.join(new_app.srcdir, "auto_examples", f)
@@ -1318,7 +1354,10 @@ def minigallery_tree(sphinx_app):
     ],
 )
 def test_minigallery_directive(minigallery_tree, test, heading, sortkey):
-    """Tests the functionality of the minigallery directive."""
+    """Tests the functionality of the minigallery directive.
+
+    Use `print(f"{test}: {lxml.html.tostring(text)}")` for checking.
+    """
     assert test in minigallery_tree
 
     text = minigallery_tree[test]
@@ -1337,6 +1376,8 @@ def test_minigallery_directive(minigallery_tree, test, heading, sortkey):
 
     if test in ["Test 1-F-R", "Test 1-S"]:
         img = text.xpath('descendant::img[starts-with(@src, "_images/sphx_glr")]')
+        # These examples are from subdir: examples_with_rst, examples_rst_index
+        # thus we look for "rst"
         href = text.xpath('descendant::a[contains(@href, "rst")]')
 
         assert img and href
@@ -1364,7 +1405,24 @@ def test_minigallery_directive(minigallery_tree, test, heading, sortkey):
             else:
                 assert not (img or href)
 
-    print(f"{test}: {lxml.html.tostring(text)}")
+
+def test_minigallery_duplicates(minigallery_tree):
+    """Ensure minigallery removes duplicate examples.
+
+    "Test duplicates" in `minigallery.rst` should result in only 2 examples:
+    - plot_second_future_imports - object (`ExplicitOrder`) AND 2 file inputs
+    - plot_numpy_matplotlib - object (`Block`) and 1 file input
+    """
+    assert "Test duplicates" in minigallery_tree
+
+    text = minigallery_tree["Test duplicates"]
+
+    imgs = text.xpath('descendant::img[starts-with(@src, "_images/sphx_glr")]')
+    expected_examples = {
+        "_images/sphx_glr_plot_second_future_imports_thumb.png",
+        "_images/sphx_glr_plot_numpy_matplotlib_thumb.png",
+    }
+    assert {img.values()[-1] for img in imgs} == expected_examples
 
 
 def test_matplotlib_warning_filter(sphinx_app):
@@ -1542,9 +1600,9 @@ def test_recommend_n_examples(sphinx_app):
     assert '<p class="rubric">Related examples</p>' in html
     assert count == n_examples
     # Check the same 3 related examples are shown (can change when new examples added)
-    assert "sphx-glr-auto-examples-plot-repr-py" in html
-    assert "sphx-glr-auto-examples-plot-matplotlib-backend-py" in html
-    assert "sphx-glr-auto-examples-plot-second-future-imports-py" in html
+    assert "sphx-glr-auto-examples-plot-defer-figures-py" in html
+    assert "sphx-glr-auto-examples-plot-webp-py" in html
+    assert "sphx-glr-auto-examples-plot-command-line-args-py" in html
 
 
 def test_sidebar_components_download_links(sphinx_app):
