@@ -228,7 +228,7 @@ def test_rst_empty_code_block(gallery_conf, tmpdir):
                     "####################",
                     "# Paragraph 1",
                     "",
-                    "# just a comment" "",
+                    "# just a comment",
                 ]
             )
         )
@@ -651,6 +651,7 @@ def test_gen_dir_rst(gallery_conf, gallery_header):
     ],
 )
 def test_gen_dir_rst_invalid_header(gallery_conf, gallery_header):
+    """Check `_get_gallery_header` raises error for invalid header extension."""
     with open(os.path.join(gallery_conf["src_dir"], gallery_header), "wb") as fid:
         fid.write("Testing\n=======\n\nÓscar here.".encode())
     with pytest.raises(ExtensionError, match="does not have a GALLERY_HEADER"):
@@ -1042,24 +1043,33 @@ def test_capture_repr(
 
 
 @pytest.mark.parametrize(
-    "caprepr_gallery, caprepr_file, expected_out",
+    "caprepr_gallery, caprepr_file, caprepr_block, expected_out",
     [
-        pytest.param(tuple(), ("__repr__",), "2", id="() --> repr"),
-        pytest.param(("__repr__",), "()", "", id="repr --> ()"),
+        pytest.param(tuple(), "()", '("__repr__",)', "2", id="() --> () --> repr"),
+        pytest.param(tuple(), ("__repr__",), None, "2", id="() --> repr --> None"),
+        pytest.param(("__repr__",), "()", None, "", id="repr --> () --> None"),
+        pytest.param(tuple(), ("__repr__",), "()", "", id="() --> repr --> ()"),
+        pytest.param(("__repr__",), "()", "()", "", id="repr --> () --> ()"),
     ],
 )
-def test_per_file_capture_repr(
+def test_capture_repr_per_file_and_per_block(
     gallery_conf,
     caprepr_gallery,
     caprepr_file,
+    caprepr_block,
     expected_out,
     req_mpl,
     req_pil,
     script_vars,
 ):
-    """Tests that per file capture_repr overrides gallery_conf."""
+    """Tests that per file/block capture_repr overrides gallery_conf."""
     compiler = codeop.Compile()
-    code_block = Block("code", "a=2\n2", 1)
+    caprepr_block = (
+        f"# sphinx_gallery_capture_repr_block={caprepr_block}\n"
+        if caprepr_block
+        else ""
+    )
+    code_block = Block("code", f"{caprepr_block}a=2\n2", 1)
     gallery_conf["capture_repr"] = caprepr_gallery
     file_conf = {"capture_repr": caprepr_file}
     output = sg.execute_code_block(
@@ -1069,7 +1079,7 @@ def test_per_file_capture_repr(
 
 
 def test_ignore_repr_types(gallery_conf, req_mpl, req_pil, script_vars):
-    """Tests output capturing with various capture_repr settings."""
+    """Tests that `ignore_repr_types` correctly ignores the output of a specific type."""
     compiler = codeop.Compile()
     code_block = Block("code", "a=2\na", 1)
     gallery_conf["ignore_repr_types"] = r"int"
@@ -1135,7 +1145,7 @@ def test_reset_module_order_3_param_invalid_when(gallery_conf):
     gallery_conf["reset_modules_order"] = "before"
     with pytest.raises(
         ValueError,
-        match=("3rd parameter in cleanup_3_param " "function signature must be 'when'"),
+        match=("3rd parameter in cleanup_3_param function signature must be 'when'"),
     ):
         _generate_rst(gallery_conf, "plot_test.py", CONTENT)
     assert mock_reset_module.call_count == 0
