@@ -3,9 +3,11 @@
 r"""Test source parser."""
 
 import os.path as op
-import pytest
 import textwrap
+
+import pytest
 from sphinx.errors import ExtensionError
+
 import sphinx_gallery.py_source_parser as sg
 
 
@@ -76,7 +78,7 @@ def test_remove_ignore_comments():
     normal_code = "# Regular code\n# should\n# be untouched!"
     assert sg.remove_ignore_blocks(normal_code) == normal_code
 
-    mismatched_code = "# sphinx_gallery_start_ignore"
+    mismatched_code = "x=5\n# sphinx_gallery_start_ignore\ny=4"
     with pytest.raises(ExtensionError) as error:
         sg.remove_ignore_blocks(mismatched_code)
     assert "must have a matching" in str(error)
